| Title: | Web App for Exploratory Data Analysis |
|---|---|
| Description: | A browser-based graphical user interface for interactive exploratory data analysis powered by the 'ggEDA' package. It enables non-programmers to explore complex multi-feature relationships, visualise missingness patterns, and generate publication-ready parallel coordinate plots and tiled one-dimensional graphics, without writing code. |
| Authors: | Sam El-Kamand [aut, cre] |
| Maintainer: | Sam El-Kamand <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-08 04:52:03 UTC |
| Source: | https://github.com/CCICB/interactiveEDA |
Run the Shiny Application
run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |